package com.emsi.tp1biir71;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;
import android.util.Log;

import androidx.annotation.Nullable;

import java.util.ArrayList;

public class MyDB extends SQLiteOpenHelper {
    private static final String DB_NAME = "etablissements.db";
    private static final int DB_VERSION = 1;
    private static  MyDB instance;

    public static final String TABLE_ETAB = "etablissements";
    public static final String COL_ID = "id";
    public static final String COL_NOM = "nom";
    public static final String COL_ADR = "adresse";
    public static final String COL_TYP = "type";

    public static MyDB getInstance(Context context) {
        if (instance == null) {
            instance = new MyDB(context);
        }
        return instance;
    }

    private MyDB(@Nullable Context context) {
        super(context, DB_NAME, null, DB_VERSION);
    }

    @Override
    public void onCreate(SQLiteDatabase db) {
        db.execSQL("CREATE TABLE " + TABLE_ETAB + " ("
                + COL_ID + " INTEGER PRIMARY KEY AUTOINCREMENT, "
                + COL_NOM + " TEXT, "
                + COL_ADR + " TEXT, "
                + COL_TYP + " TEXT)");
    }

    @Override
    public void onUpgrade(SQLiteDatabase db, int i, int i1) {
        /// TODO: requêtes de passage entre-versions
    }

    public void addEtab(Etab etab) {
        ContentValues row =new ContentValues();
        row.put(COL_NOM,etab.getNom());
        row.put(COL_ADR,etab.getAdresse());
        row.put(COL_TYP,etab.getType());
        getWritableDatabase().insert(TABLE_ETAB,null, row);
    }

    public void deleteEtab(int id) {
        getWritableDatabase().delete(TABLE_ETAB,COL_ID+"=?",
                new String[]{String.valueOf(id)});
    }

    public ArrayList<Etab> getAllEtab() {
        ArrayList<Etab> etabList = new ArrayList<>();
        Cursor c = getReadableDatabase().query(TABLE_ETAB,
                new String[]{COL_ID, COL_NOM, COL_ADR, COL_TYP},
                null, null, null, null, COL_NOM);
        if (c.moveToFirst()) {
            do {
                etabList.add(
                    new Etab(c.getInt(c.getColumnIndexOrThrow(COL_ID)),
                        c.getString(c.getColumnIndexOrThrow(COL_NOM)),
                        c.getString(c.getColumnIndexOrThrow(COL_ADR)),
                        c.getString(c.getColumnIndexOrThrow(COL_TYP))));
            } while (c.moveToNext());
        }
        Log.d("MyDB",etabList.size()+"");
        c.close();
        return etabList;
    }
}
